@@ -347,6 +347,47 @@ static void test_uintset_intersect_test(const void *user_data)
 	l_uintset_free(set_r);
 }
 
+static void test_uintset_isempty(const void *user_data)
+{
+	struct l_uintset *a = NULL;
+	struct l_uintset *b = l_uintset_new(32);
+	struct l_uintset *c = l_uintset_new(32);
+
+	assert(l_uintset_put(c, 10));
+
+	assert(l_uintset_isempty(a));
+	assert(l_uintset_isempty(b));
+	assert(!l_uintset_isempty(c));
+
+	l_uintset_free(c);
+	l_uintset_free(b);
+}
+
+static void test_uintset_size(const void *user_data)
+{
+	uint32_t i;
+	struct l_uintset *set = l_uintset_new(32);
+
+	assert(l_uintset_size(set) == 0);
+
+	for (i = 1; i < 32; i++) {
+		assert(l_uintset_put(set, i));
+		assert(l_uintset_size(set) == i);
+	}
+
+	assert(l_uintset_size(set) == i - 1);
+
+	assert(l_uintset_take(set, 10));
+	assert(l_uintset_size(set) == i - 2);
+
+	for (i = 1; i < 32; i++)
+		assert(l_uintset_take(set, i));
+
+	assert(l_uintset_size(set) == 0);
+
+	l_uintset_free(set);
+}
+
 int main(int argc, char *argv[])
 {
 	l_test_init(&argc, &argv);
@@ -364,6 +405,8 @@ int main(int argc, char *argv[])
 							&intersect_data_1);
 	l_test_add("l_uintset intersect test 2", test_uintset_intersect_test,
 							&intersect_data_2);
+	l_test_add("l_uintset isempty", test_uintset_isempty, NULL);
+	l_test_add("l_uintset size", test_uintset_size, NULL);
 
 	return l_test_run();
 }
